@@ -1,4 +1,4 @@
-/*      $Id: hints.c 23704 2006-11-04 22:36:42Z olivier $
+/*      $Id: hints.c 24107 2006-12-14 21:49:51Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -24,9 +24,11 @@
 #include <config.h>
 #endif
 
+#include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xmd.h>
+
 #include <glib.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
@@ -36,6 +38,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <libxfce4util/libxfce4util.h>
+
 #include "display.h"
 #include "screen.h"
 #include "hints.h"
@@ -953,7 +956,7 @@ getNetWMUserTime (DisplayInfo *display_info, Window window, Time *time)
 
     TRACE ("entering getNetWMUserTime");
 
-    g_return_val_if_fail (window != None, None);
+    g_return_val_if_fail (window != None, FALSE);
 
     if (XGetWindowProperty (display_info->dpy, window, display_info->atoms[NET_WM_USER_TIME],
                             0L, 1L, FALSE, XA_CARDINAL, &actual_type, &actual_format, &nitems,
@@ -967,7 +970,8 @@ getNetWMUserTime (DisplayInfo *display_info, Window window, Time *time)
             return TRUE;
         }
     }
-    *time = 0L;
+    *time = (Time) 0;
+
     return FALSE;
 }
 
@@ -1140,11 +1144,11 @@ setXAtomManagerOwner (DisplayInfo *display_info, Atom atom, Window root, Window
         ev.type = ClientMessage;
         ev.message_type = atom;
         ev.format = 32;
-        ev.data.l[0] = server_time;
-        ev.data.l[1] = atom;
-        ev.data.l[2] = w;
-        ev.data.l[3] = 0;
-        ev.data.l[4] = 0;
+        ev.data.l[0] = (long) server_time;
+        ev.data.l[1] = (long) atom;
+        ev.data.l[2] = (long) w;
+        ev.data.l[3] = (long) 0L;
+        ev.data.l[4] = (long) 0L;
         ev.window = root;
 
         XSendEvent (display_info->dpy, root, FALSE, StructureNotifyMask, (XEvent *) &ev);
@@ -1196,38 +1200,49 @@ getXServerTime (DisplayInfo *display_info)
 
     g_return_val_if_fail (display_info, (Time) CurrentTime);
     timestamp = myDisplayGetCurrentTime (display_info);
-    if (timestamp == CurrentTime)
+    if (timestamp == (Time) CurrentTime)
     {
         screen_info = myDisplayGetDefaultScreen (display_info);
         g_return_val_if_fail (screen_info,  (Time) CurrentTime);
 
+        TRACE ("getXServerTime: Using X server roundtrip");
         XChangeProperty (display_info->dpy, screen_info->xfwm4_win, 
                          display_info->atoms[XFWM4_TIMESTAMP_PROP],
                          display_info->atoms[XFWM4_TIMESTAMP_PROP],
                          8, PropModeReplace, (unsigned char *) &c, 1);
         XIfEvent (display_info->dpy, &xevent, checkPropEvent, (XPointer) display_info);
 
-        timestamp = (Time) xevent.xproperty.time;
+        timestamp = (Time) myDisplayUpdateCurrentTime (display_info, &xevent);
     }
+
+    TRACE ("getXServerTime gives timestamp=%u", (unsigned int) timestamp);
     return timestamp;
 }
 
 #ifdef ENABLE_KDE_SYSTRAY_PROXY
 gboolean
-checkKdeSystrayWindow(DisplayInfo *display_info, Window window)
+checkKdeSystrayWindow (DisplayInfo *display_info, Window window)
 {
     Atom actual_type;
     int actual_format;
     unsigned long nitems;
     unsigned long bytes_after;
+    unsigned char *data;
     Window trayIconForWindow;
 
-    TRACE ("entering GetWindowRole");
+    TRACE ("entering checkKdeSystrayWindow");
     g_return_val_if_fail (window != None, FALSE);
 
     XGetWindowProperty(display_info->dpy, window, display_info->atoms[KDE_NET_WM_SYSTEM_TRAY_WINDOW_FOR],
                        0L, sizeof(Window), FALSE, XA_WINDOW, &actual_type, &actual_format,
-                       &nitems, &bytes_after, (unsigned char **) &trayIconForWindow);
+                       &nitems, &bytes_after, (unsigned char **) &data);
+
+    trayIconForWindow = None;
+    if (data)
+    {
+        trayIconForWindow = *((Window *) data);
+        XFree (data);
+    }
 
     if ((actual_format == None) ||
         (actual_type != XA_WINDOW) ||
@@ -1235,6 +1250,7 @@ checkKdeSystrayWindow(DisplayInfo *display_info, Window window)
     {
         return FALSE;
     }
+
     return TRUE;
 }
 
@@ -1251,11 +1267,11 @@ sendSystrayReqDock(DisplayInfo *display_info, Window window, Window systray)
     xev.window = systray;
     xev.message_type = display_info->atoms[NET_SYSTEM_TRAY_OPCODE];
     xev.format = 32;
-    xev.data.l[0] = myDisplayGetCurrentTime (screen_info);
-    xev.data.l[1] = 0; /* SYSTEM_TRAY_REQUEST_DOCK */
-    xev.data.l[2] = window;
-    xev.data.l[3] = 0; /* Nada */
-    xev.data.l[4] = 0; /* Niet */
+    xev.data.l[0] = (long) myDisplayGetCurrentTime (display_info);
+    xev.data.l[1] = (long) 0L; /* SYSTEM_TRAY_REQUEST_DOCK */
+    xev.data.l[2] = (long) window;
+    xev.data.l[3] = (long) 0L; /* Nada */
+    xev.data.l[4] = (long) 0L; /* Niet */
 
     XSendEvent (display_info->dpy, systray, FALSE, NoEventMask, (XEvent *) & xev);
 }
@@ -1341,11 +1357,11 @@ sendXSyncRequest (DisplayInfo *display_info, Window window, XSyncValue value)
     xev.window = window;
     xev.message_type = display_info->atoms[WM_PROTOCOLS];
     xev.format = 32;
-    xev.data.l[0] = display_info->atoms[NET_WM_SYNC_REQUEST];
-    xev.data.l[1] = CurrentTime;
-    xev.data.l[2] = XSyncValueLow32 (value);
-    xev.data.l[3] = XSyncValueHigh32 (value);
-    xev.data.l[4] = 0;
+    xev.data.l[0] = (long) display_info->atoms[NET_WM_SYNC_REQUEST];
+    xev.data.l[1] = (long) myDisplayGetCurrentTime (display_info);
+    xev.data.l[2] = (long) XSyncValueLow32 (value);
+    xev.data.l[3] = (long) XSyncValueHigh32 (value);
+    xev.data.l[4] = (long) 0L;
     XSendEvent (display_info->dpy, window, FALSE, NoEventMask, (XEvent *) &xev);
 }
 #endif /* HAVE_XSYNC */
